//   $Id: bsac.h,v 1.1.1.1 2022/12/27 22:03:00 pm Exp $
//...bsac header (SAC Compatible Header Structure for BSU)
//  P. Michaels <paulmichaels@boisestate.edu>
//  Based on the Seismic Analysis Code Data Format published by IRIS
//	usually independent variable is time, dependent a seismic signal
//	REF: http://www.iris.edu/software/sac
	struct	sacheader
	{
	float	DELTA;	//sample interval (required)
	float	DEPMIN;	//min value dependent variable
	float	DEPMAX;	//max value dependent variable
	float	SCALE;	//UNUSED scale factor to multiply dep. var.
	float	ODELTA;	//observed sample interval if different from delta
	float	B;	//begining value of indep. variable (required)
	float	E;	//ending value of indep. variable (required)
	float	O;	//event origin time seconds (sec.) wrt reference time
	float	A;	//first arrival time seconds (sec.) wrt reference time
	float	I009;	//internal sac word 09
	float	T0;	//user defined time pick (sec.) wrt reference time
	float	T1;	//user defined time pick (sec.) wrt reference time
	float	T2;	//user defined time pick (sec.) wrt reference time
	float	T3;	//user defined time pick (sec.) wrt reference time
	float	T4;	//user defined time pick (sec.) wrt reference time
	float	T5;	//user defined time pick (sec.) wrt reference time
	float	T6;	//user defined time pick (sec.) wrt reference time
	float	T7;	//user defined time pick (sec.) wrt reference time
	float	T8;	//user defined time pick (sec.) wrt reference time
	float	T9;	//user defined time pick (sec.) wrt reference time
	float	F;	//fini (end of event time (sec.) wrt reference time
	float	RESP0;	//instrument response parameter (not currently used)
	float	RESP1;	//instrument response parameter (not currently used)
	float	RESP2;	//instrument response parameter (not currently used)
	float	RESP3;	//instrument response parameter (not currently used)
	float	RESP4;	//instrument response parameter (not currently used)
	float	RESP5;	//instrument response parameter (not currently used)
	float	RESP6;	//instrument response parameter (not currently used)
	float	RESP7;	//instrument response parameter (not currently used)
	float	RESP8;	//instrument response parameter (not currently used)
	float	RESP9;	//instrument response parameter (not currently used)
	float	STLA;	//station latitude (degrees, positive north)
	float	STLO;	//station longitude (degrees east positive)
	float 	STEL;	//station elevation (meters)
	float	STDP;	//station depth below surface (meters)
	float	EVLA;	//event latitude (degrees, positive north)
	float 	EVLO;	//event longitude (degrees, positive east)
	float	EVEL;	//event elevation (meters)
	float	EVDP;	//event depth (meters)
	float	MAG;	//event magnitude
	float	USER0;	//user defined storage area
	float	USER1;	//user defined storage area
	float	USER2;	//user defined storage area
	float	USER3;	//user defined storage area
	float	USER4;	//user defined storage area
	float	USER5;	//user defined storage area
	float	USER6;	//user defined storage area
	float	USER7;	//user defined storage area
	float	USER8;	//user defined storage area
	float	USER9;	//user defined storage area
	float	DIST;	//station to event distance KM
	float	AZ;	//event to station azimuth (degrees)	
	float	BAZ;	//station to event azimuth (degrees)
	float	GCARC;	//station to event great circle arc length (degrees)
	float	I054;	//internal, word 54
	float	I055;	//internal, word 55
	float	DEPMEN;	//mean value of dependent variable
	float	CMPAZ;	//component azimuth (degrees clockwise from north)	
	float	CMPINC;	//component inclination (degrees from vertical)
	float	XMINIMUM;	//minimum x-value spectral files only
	float	XMAXIMUM;	//maximum x-value spectral files only
	float	YMINIMUM;	//minimum y-value spectral files only
	float	YMAXIMUM;	//maximum y-value spectral files only
	float	U063;	//unused word 63	
	float	U064;	//unused word 64	
	float	U065;	//unused word 65	
	float	U066;	//unused word 66	
	float	U067;	//unused word 67	
	float	U068;	//unused word 68	
	float	U069;	//unused word 69	
	int	NZYEAR;	//GMT year corresponding to reference (zero time) in file
	int	NZJDAY;	//GMT julian day
	int	NZHOUR;	//GMT julian hour
	int	NZMIN;	//GMT minute
	int	NZSEC;	//GMT second
	int	NZMSEC;	//GMT millisecond
	int	NVHDR;	
	int	NORID;
	int	NEVID;
	int	NPTS;	//number of samples in signal (required)	
	int	I080;	//internal, word 80	
	int	NWFID;
	int	NXSIZE;
	int	NYSIZE;
	int	U084;	//unused word 84
	int	IFTYPE;	//Type of file (required) (see inc/SacHeader.h or extfunc.h)
		/* 1 = ITIME = time series data
		   2 = IRLIM = real & imag spectrum
		   3 = IAMPH = spectral file, amplitude and phase
		   4 = IXY   = general x vs y data
		   5 = IXYZ  = general x,y,z (3-D)file
		*/
	int	IDEP;	//Type of independent variable
		/* 5 = IUNKN = x data type unknown
		   6 = IDISP = x data displacement data (nm)
		   7 = IVEL  = x data velocity in nm/second
		  50 = IVOLTS =x data velocity signal in volts
		   8 = IACC  = x data accel (nm/sec/sec)  	
		*/	
	int	IZTYPE;	//reference time equivalence:
		/* 5 = IUNKN = unknown
		   9 = IB = zero time: start of file
		  10 = IDAY = zero time: 0000 of GMT day
		  11 = IO  = zero time: event origin
		  12 = IA  = zero time: 1st arrival
		 13-22 = ITn = user defined pick time n, n=0..9
			IT0=13, IT1=14, ....IT9=22
		*/
	int	U088;
	int	IINST;	//type of recording instrument (not currently used)	
	int	ISTREG;	//station geographic region (not used)
	int	IEVREG;	//event geographic region (not used)
	int	IEVTYP;	//event type
		/* 5 = IUNKN = unknown
		  37 = INUCL = nuclear event
		  38 = IPREN = nuke pre-shot
		  39 = IPOSTN = nuclear post-shot event
		  40 = IQUAKE = earthquake
		  41 = IPREQ = foreshock
		  42 = IPOSTQ = aftershock
		  43 = ICHEM = chemical explosion
		  72 = IQB = quarry or mine blast confirmed by quarry
		  73 = IQB1 = quarry or mine blast with designed
				shot info=ripple fired
		  74 = IQB2 = quarry or mine blast with
				observed shot info-ripple fired
		  75 = IQBX = quarry or mine blast, single shot
		  80 = IME  = marine explosion
		  77 = IEQ  = earthquake
		  78 = IEQ1 = earthquakes in a swarm or aftershock sequence
		  79 = IEQ2 = felt earthquake
		  44 = IOTHER = other
		*/
	int	IQUAL;
	int	ISYNTH;
	int	IMAGTYP;
	int	IMAGSRC;
	int	U097;	//unused word 97
	int	U098;	//unused word 98
	int	U099;	//unused word 99
	int	U100;	//unused word 100
	int	U101;	//unused word 101
	int	U102;	//unused word 102
	int	U103;	//unused word 103
	int	U104;	//unused word 104
	int	LEVEN;	// REQUIRED even spaced data = logical true = 1
	int	LPSPOL;	//logical 1=true 0=false
	int	LOVROK;	//logical 1=true 0=false
	int	LCALDA;	//logical 1=true 0=false
	int	U109;	//unused word 109	
	char	KSTNM[8];	// station name (8char=2words)
	char	KEVNM[16];	// event name
	char	KHOLE[8];
	char	KO[8];
	char	KA[8];
	char	KT0[8];
	char	KT1[8];
	char	KT2[8];
	char	KT3[8];
	char	KT4[8];
	char	KT5[8];
	char	KT6[8];
	char	KT7[8];
	char	KT8[8];
	char	KT9[8];
	char	KF[8];
	char	KUSER0[8];
	char	KUSER1[8];
	char	KUSER2[8];
	char	KCMPNM[8];
	char	KNETWK[8];
	char	KDATRD[8];
	char	KINST[8];
	};

