/* |--------------------------------------------------|
   | sub4.h                                           |
   | author: P. Michaels                              |
   | dated: 21 May 1997                               |
   |                                                  |
   | purpose: include file for subroutine library     |
   |          sub4.lib                                |
   |                                                  |
   |--------------------------------------------------|
*/

//...function prototypes

                   // BASIC BSEGY FUNCTIONS

// Print Copyright label, time, date to screen
      void cr_labl(char pid[]);

// Print Help Panel to screen
      void hlp_labl(char msg1[],  char  msg2[]);

// Print Copyright label, time, date to file h3
      void fcr_labl(char pid[], FILE *h3);

// Generate output and listing file names
      void names(char infile[], char pid[], char ofile[],
        char suffix[]);

// Count traces, return number samples, interval
      int in_chk(int *ntraces, int *npts,
        float *fsamin, struct header hd, FILE *h1);

// Read a bsegy header+trace from file h1
      int c_bsegin(int jrec, float s1[], int npts,
        struct header *hd, FILE *h1);

// Write a bsegy header+trace to file h2
      int c_bsegout(int jrec, float s1[], int npts,
        struct header *hd, FILE *h2);

// Compute exbar parameters and draw progress bar
      void bargrid(int ntraces, float *bar, int *ibar, int *invbar);

// Write a progress bar step for jrec into ntraces
      void exbar(int ntraces, float bar, int ibar, int invbar, int jrec);

/*  Compute x,y,z coordinates and range of shot and receivers
                    *sx       =pointer shot x-coord.
                    *sy       =pointer shot y-coord.
                    *sz       =pointer shot z-coord.
                    *sd       =pointer shot depth
                    *rx       =pointer receiver x-coord.
                    *ry       =pointer receiver y-coord.
                    *rz       =pointer receiver z-coord.
                    *range    =pointer range from shot to receiver
                    hd        =segy header structure
*/

      void findxyz(float *sx, float *sy, float *sz, float *sd,
         float *rx, float *ry, float *rz, float *range,
         struct header hd);



                 // SIGNAL PROCESSING FUNCTIONS

/* Boxcar smoothing
                     npts     =number of samples
                     iwide    =width of box in samples
                     ntimes   =number of times to apply
                     isign  -1=box car smoother (sinc^ntimes)
                             0=high-pass 1-sinc^ntimes
                            +1=high-pass (1-sinc)^ntimes
                     s1       =input trace array
                     s2       =output trace array
   returns: 0=success   1=abort, can't allocate memory
                          (or invalid parameters)
*/
      int c_boxit(int npts,int iwide,int isign,int ntimes,
         float s1[], float s2[]);

/* Find max and min values
                     npts     =number of samples
                     s1       =input trace
                     isw1    0=max and min of s1
                             1=max and min of absolute_value(s1)
                    *fmax     =pointer to max value
                    *fmin     =pointer to min value
                    *kmx      =pointer to max value index
                    *kmn      =pointer to min value index
*/
      void fmax_min(int npts, float s1[],
         float *fmax, float *fmin, int isw1,  int *kmx,  int *kmn);

/* Single Pole smoother ARMA operator
                     npts     =number of samples
                     s1       =input trace array
                     fsamin   =sample interval (s)
                     tcond    =decay constant (amp=>1/e) (s)
                     s2       =output trace array
   returns: 0=success   1=invalid parameters
*/
      int onepole(int npts, float fsamin, float tcond,
         float s1[],float s2[]);

/* Normalization Function
                     npts     =number of samples
                     s1       =input trace array
                    *fscal   0=normalize by L2 norm
                              =scale factor 1/(*fscal)
                     s2       =output trace array
   returns: 0=success   1=invalid parameters
*/
      int  fnorm(int npts, float *fscal, float s1[], float s2[]);


/*  Compute Mean Absolute Value
                     npts     =number of samples
                     s1       =input trace array
   returns MAV as float value
*/
      float mav(int npts,float s1[]);

/*  Least Squares Linear or Exponential Fit to x,y data
    isw1   0=Linear 1=Log_e for y-variable  
*/
      void lsqufit(float x[], float y[], int npts, int isw1,
         float *slope, float *intrcpt, float *lsqe, float *r2);

/*  Buffer overflow protection on input file names  */
     int  namecheck(int length, char name[] );

/*  Function to write seg-2 format data out */
     int WriteSEG2(int npts, int nchnl, float fsamin, int s2[], float DELAY,
	char rawrecord[], int stack, char source[], char phones[], double DSF,
	short int AIF, short int AIS, short int FLC, short int SLC, short int FHC,
	short int SHC, short int GIDB,
	short nSP, float sx, float sy, float sz,
	float rx[], float ry[], float rz[],
	char TIME[], char DATE[], char STRING[]);  





#define BUFLEN 1024 
