%   |------------------------------------------------------------|
%   | $Id: seisazi.m,v 1.1.1.1 2022/12/27 22:03:00 pm Exp $          |
%   | Basic Seismic Utilities (BSU)                              |
%   | LANGUAGE: octave                                           |
%   | AUTHOR: P. MICHAELS                                        |
%   | FUNCTION NAME: seisazi.m                                   |
%   | DIRECTORY: BSUROOT/octave                                  |
%   |  revised for OCTAVE                                        |
%   |------------------------------------------------------------|
%   | purpose: read a BSEGY file and plot geophone element       |
%   |          azimuth of horizontal component.                  |
%   |                                                            |
%   |------------------------------------------------------------|
%   | octave is an interpreter useful for scientifc calculations.|
%   | It is similar to MATLAB and may be obtained free from      |
%   | http://www.gnu.org/software/octave                         |
%   |------------------------------------------------------------|
%   |  NOTICE:                                                   |
%   |  Copyright (c) 2017 Paul Michaels                          |
%   |  <pm@cgiss.boisestate.edu>                                 |
%   |  This program is free software; you can                    |
%   |  redistribute it and/or modify it under the terms          |
%   |  of the GNU General Public License as published            |
%   |  by the Free Software Foundation; either version           |
%   |  3 of the License, or (at your option) any later           |
%   |  version.  This program is distributed in the              |
%   |  hope that it will be useful, but                          |
%   |  WITHOUT ANY WARRANTY; without even the implied            |
%   |  warranty of MERCHANTABILITY or FITNESS FOR A              |
%   |  PARTICULAR PURPOSE.  See the GNU General Public           |
%   |  License for more details.                                 |
%   |  You should have received a copy of the GNU                |
%   |  General Public License along with this program;           |
%   |  if not, write to the Free Software Foundation,            |
%   |  Inc., 675 Mass Ave, Cambridge, MA 02139, USA.             |
%   |------------------------------------------------------------|
clear
%fflush(stdout)
filen=input('enter file name ','s');
fp1=fopen(filen,'r');

%read *.seg file info:  ntraces=number of traces
%                       npts=number samples per trace
%                       fsamin=sample interval in seconds
[nbytes,ntraces,npts,fsamin]=segyinfo(fp1);

%read trace number jtrace by call to bsegin
%        data=vector of digitized samples
%        frange=source receiver separation
%        pic=first arrival time pick if any
%        rx,ry,rz=geophone coordinates
%        sx,sy,sz=source coordinates
%        sd=source depth, below sz
xstr=sprintf('  %s \n %d traces tmax=%.3f sec. dt=%.5f',...
             filen,ntraces,npts*fsamin,fsamin);
msgbox(xstr);

%compute time vector for plot

tm=1:npts;
tm=tm*fsamin;

for k=1:ntraces
[data,frange,pic,rx,ry,rz,sx,sy,sz,sd,sp,vp,geoazi]=bsegin(fp1,npts,k);
szsv(k)=sz;
rzsv(k)=rz;
gazi(k)=geoazi;
end  % next k
fclose(fp1);

y=zeros(ntraces,1);
x=zeros(ntraces,1);
for j=1:ntraces
x(j)=gazi(j);
y(j)=szsv(j)-rzsv(j);
end
% plot azimuth of horizontal component
plot(x,-y,'-b');
xlabel('Azimuth (degrees)');
ylabel('Depth (m)');
title(xstr)
axis([0,360,min(-y),max(-y)]);
grid

