%   |------------------------------------------------------------|
%   | $Id: soilprofile.m,v 1.2 2024/06/05 23:06:08 pm Exp $       |
%   | Basic Seismic Utilities (BSU)                              |
%   | LANGUAGE: octave                                           |
%   | AUTHOR: P. MICHAELS                                        |
%   | FUNCTION NAME: soilprofile                                 |
%   | REQUIRES: Model.txt (see below)                            |
%   | DIRECTORY: BSUROOT/Octave                                  |
%   |  revised for OCTAVE                                        |
%   |------------------------------------------------------------|
%   | purpose: compute a soil profile considering properties     |
%   | like Poison's ratio, porosity, degree water saturation     |
%   |------------------------------------------------------------|
%   | octave is an interpreter useful for scientifc calculations.|
%   | It is similar to MATLAB and may be obtained free from      |
%   | http://www.gnu.org/software/octave                         |
%   |------------------------------------------------------------|
%   |  NOTICE:                                                   |
%   |  Copyright (c) 2024 Paul Michaels                          |
%   |  <pm@cgiss.boisestate.edu>                                 |
%   |  This program is free software; you can                    |
%   |  redistribute it and/or modify it under the terms          |
%   |  of the GNU General Public License as published            |
%   |  by the Free Software Foundation; either version           |
%   |  3 of the License, or (at your option) any later           |
%   |  version.  This program is distributed in the              |
%   |  hope that it will be useful, but                          |
%   |  WITHOUT ANY WARRANTY; without even the implied            |
%   |  warranty of MERCHANTABILITY or FITNESS FOR A              |
%   |  PARTICULAR PURPOSE.  See the GNU General Public           |
%   |  License for more details.                                 |
%   |  You should have received a copy of the GNU                |
%   |  General Public License along with this program;           |
%   |  if not, write to the Free Software Foundation,            |
%   |  Inc., 675 Mass Ave, Cambridge, MA 02139, USA.             |
%   |------------------------------------------------------------|

clear
%Model.txt FILE Definition
% set Vs,Vp,Rho based on soil parameters
% Model.txt has 6 rows
% nlay                             <==number of layers
% vs_1, vs_2, ... vs_nlay          <==shear velocity
% zi_1, zi_2, ... zi_nlay          <==depths
% por_1, por_2, ... por_nlay       <==porosities
% sigma_1, sigma_2, ...sigma_nlay  <==Poisson's ratio
% Sat_1, Sat_2, ...Sat_nlay        <==degree water saturation


function [alpha,beta1]=e2v(Rho,Mu,Lame)
beta1=sqrt(Mu./Rho);
alpha=sqrt(Lame./Rho+2*beta1^2);
endfunction


Query=sprintf('enter file with initial model \n example: Model.txt ');
ifile=input(Query,'s');
invar=ifile(1: findstr(ifile,'.')-1);
fp1=fopen(ifile);
[invar]=fscanf(fp1,'%f');
nlay=invar(1)
Beta(1:nlay)=invar(2:1+nlay) %Vs
zi(1:nlay)=invar(2+nlay:1+nlay+nlay) %depths
npor(1:nlay)=invar(2+2*nlay:1+nlay+nlay+nlay) %porosities
sigma(1:nlay)=invar(2+3*nlay:1+4*nlay) %Poisson's ratio
Sat(1:nlay)=invar(2+4*nlay:1+5*nlay) %Degree water saturation
fclose(fp1)


%Can adjust these as needed
Gs=2.67;    %grain density



for j=1:nlay
evr=npor/(1-npor(j)); %void ratio
rhomoist=((Gs+Sat(j)*evr)*1000)/(1+evr);  %mass density soil
alphaObeta=sqrt( 2*(1-sigma(j)) / (1-2*sigma(j)));
Alpha(j,1)=Beta(j)*alphaObeta; %P-wave velocities
rho(j,1)=rhomoist; %Densities
end

%soil profile 
X=[Beta',Alpha,rho,zi']

save -ascii profile.txt X

