     #include <octave/oct.h>
     #include <octave/f77-fcn.h>
     
     extern "C"
     {
       F77_RET_T
       F77_FUNC (wavsub, FORTSUB)
             (const int&, double*, double*,
		double*, double*,
                double*, const int&, double*,  double*,
                double*, 
                const int&, 
                double*, double*, double*, double*,
                const int&, double*, double*);
     }
     
     DEFUN_DLD (waves , args , , "Rayleigh Wave Synthetic")
     {
//       octave_value_list    retval;
       int nargin = args.length();
       if (nargin != 14)
         print_usage ();


           NDArray Freq   = args(0).array_value (); //frequency array
           NDArray pv     = args(1).array_value (); //dispersion phase vel. array
           NDArray fsamin = args(2).array_value (); //sample interval
           NDArray firvsel = args(3).array_value ();//switch: vert or horiz out 
           NDArray sxyz = args(4).array_value ();   //source location x,y,z
           NDArray rx = args(5).array_value ();     //receiver location arrays rx
           NDArray ry = args(6).array_value ();     // ry
           NDArray rz = args(7).array_value ();     // rz
           NDArray rho = args(8).array_value ();    // mass density array
           NDArray mu = args(9).array_value ();     // shear moduls array
           NDArray lame = args(10).array_value ();  // Lame's constant array
           NDArray zi = args(11).array_value ();    // depth boudary array
           NDArray xout = args(12).array_value ();  // seismic traces
           NDArray segsw = args(13).array_value ();//switch: output BSEGY file 

	/*   Octave call:
		waves(Freq,pv,fsamin,firvselv,sxyz,rx,ry,rz,rho,mu,lame,zi,xout,segsw)

	*/  
               double *Freqv         = Freq.fortran_vec (); // frequency array
               octave_idx_type Nfreq = Freq.numel ();       // number of frequencies 
               double *pvv           = pv.fortran_vec ();   // dispersion velocities
               double *fsaminv = fsamin.fortran_vec ();     // sample interval sec.
               double *firvselv = firvsel.fortran_vec ();   // switch: vert or horiz out
               double *sxyzv = sxyz.fortran_vec ();         // source location x,y,z
               octave_idx_type nrec = rx.numel ();          // number of receivers
               double *rxv = rx.fortran_vec ();             // receiver locations, rx
               double *ryv = ry.fortran_vec ();		    //  ry	
               double *rzv = rz.fortran_vec ();             //  rz
               double *rhov = rho.fortran_vec ();           // density array
               double *muv = mu.fortran_vec ();	            // shear modulus array
               double *lamev = lame.fortran_vec ();         // Lame' constant array
               double *ziv = zi.fortran_vec ();             // depth layer boundary 
               octave_idx_type nlay = rho.numel ();         // number of layers
               double *xoutv = xout.fortran_vec ();         // seismic traces concatonated
	       octave_idx_type Nxout = xout.numel ();       // Nxout=nrec*npts   
               double *segswv = segsw.fortran_vec ();   // switch: output BSEGY file

	/*  Fortran subroutine call:
		wavsub(Nfreq,Freq,pv,fsamin,firvsel,sxyz,rx,ry,rz,rho,mu,lame,zi,Nxout,xout)

	*/     
               F77_XFCN (wavsub, FORTSUB, (Nfreq,Freqv,pvv,fsaminv,
               firvselv,sxyzv,nrec,rxv,ryv,rzv,nlay,rhov,muv,lamev,ziv,Nxout,xoutv,segswv) );

	return ovl (Nxout,xout);
     }

